@@ -14,8 +14,7 @@ class BaseAction(object):
     origin: str
     sign_type: str = dataclasses.field(init=False)
     chain_id: int = dataclasses.field(init=False)
-    user_addr: str = dataclasses.field(init=False)
-
+    
     def __post_init__(self):
         pass
 
@@ -33,6 +32,7 @@ class TransactionAction(BaseAction):
 @dataclasses.dataclass()
 class TextAction(BaseAction):    
     text: str
+    user_addr: str
         
     def __post_init__(self):
         super(TextAction, self).__post_init__()
@@ -43,6 +43,7 @@ class TextAction(BaseAction):
 class TypedDataAction(BaseAction):
 
     typed_data: dict
+    user_addr: str
     
     def __post_init__(self):
         super(TypedDataAction, self).__post_init__()
